# opentc-util

This is the utility/base module for the opentc, opentc-icap and opentc-web. It includes 
mainly the client and simplesocket functions which can be used to communicate with the
opentcd server.
